gguf_weight_encoding

Function gguf_weight_encoding 

pub fn gguf_weight_encoding(ggml_type: u32) -> Result<WeightEncoding>
Describes physical bytes only. An accepted encoding does not imply that an operation provider exists for any particular device or model tensor role.